@@ -12,64 +12,62 @@ import {
 } from '@console/shared/src/test-utils/utils';
 import { VirtualMachineModel } from '@console/kubevirt-plugin/src/models';
 import { createNICButton } from '../views/kubevirtUIResource.view';
-import { nicType } from '../views/dialogs/networkInterface.view';
+import { nicModel, nicType } from '../views/dialogs/networkInterface.view';
 import { getInterfaces } from '../../src/selectors/vm/selectors';
 import { getVMIDisks } from '../../src/selectors/vmi/basic';
 import * as wizardView from '../views/wizard.view';
+import { dropDownList, dropDownItemMain } from '../views/uiResource.view';
 import {
   multusNAD,
   hddDisk,
   multusNetworkInterface,
   getVMManifest,
-  basicVMConfig,
-  defaultWizardPodNetworkingInterface,
-  defaultYAMLPodNetworkingInterface,
-} from './utils/mocks';
+  defaultPodNetworkingInterface,
+} from './mocks/mocks';
+import { getBasicVMBuilder } from './mocks/vmBuilderPresets';
 import {
-  getSelectOptions,
+  getListTexts,
   getRandomMacAddress,
-  getRandStr,
   createExampleVMViaYAML,
   getResourceObject,
+  selectItemFromDropdown,
 } from './utils/utils';
 import {
-  VM_BOOTUP_TIMEOUT_SECS,
+  VM_IMPORT_TIMEOUT_SECS,
   VM_ACTIONS_TIMEOUT_SECS,
-  TAB,
-  VM_ACTION,
-  NIC_MODEL,
-  NIC_TYPE,
-  DISK_SOURCE,
-  networkTabCol,
   DEFAULT_YAML_VM_NAME,
-} from './utils/consts';
+} from './utils/constants/common';
+import { VM_ACTION, VM_STATUS, NIC_MODEL, NIC_TYPE, networkTabCol } from './utils/constants/vm';
 import { VirtualMachine } from './models/virtualMachine';
 import { Wizard } from './models/wizard';
 import { NetworkInterfaceDialog } from './dialogs/networkInterfaceDialog';
+import { VMBuilder } from './models/vmBuilder';
+import { ProvisionSource } from './utils/constants/enums/provisionSource';
 
 describe('Add/remove disks and NICs on respective VM pages', () => {
-  const testVm = getVMManifest('Container', testName, `vm-disk-nic-${testName}`);
-  const vm = new VirtualMachine(testVm.metadata);
+  const testVM = getVMManifest(ProvisionSource.URL, testName, `vm-disk-nic-${testName}`);
+  const vm = new VirtualMachine(testVM.metadata);
 
   beforeAll(async () => {
-    createResources([multusNAD, testVm]);
-  }, VM_BOOTUP_TIMEOUT_SECS);
+    createResources([multusNAD, testVM]);
+    await vm.waitForStatus(VM_STATUS.Off, VM_IMPORT_TIMEOUT_SECS);
+  });
 
   afterAll(() => {
-    deleteResources([multusNAD, testVm]);
+    deleteResources([multusNAD, testVM]);
   });
 
   it(
     'ID(CNV-1502) Add/remove disk on VM disks page',
     async () => {
       await vm.addDisk(hddDisk);
-      expect(await vm.getAttachedDisks()).toContain(hddDisk);
-      await vm.action(VM_ACTION.Start);
+      expect(await vm.hasDisk(hddDisk)).toBeTruthy();
+      await vm.detailViewAction(VM_ACTION.Start);
       const vmi = getResourceObject(vm.name, vm.namespace, 'VirtualMachineInstance');
       expect(_.find(getVMIDisks(vmi), (o) => o.name === hddDisk.name)).toBeDefined();
-      await vm.action(VM_ACTION.Stop);
+      await vm.detailViewAction(VM_ACTION.Stop);
       await vm.removeDisk(hddDisk.name);
-      expect(await vm.getAttachedDisks()).not.toContain(hddDisk);
+      expect(await vm.hasDisk(hddDisk)).not.toBeTruthy();
     },
     VM_ACTIONS_TIMEOUT_SECS,
   );
@@ -78,14 +76,14 @@ describe('Add/remove disks and NICs on respective VM pages', () => {
     'ID(CNV-1501) Add/remove nic on VM Network Interfaces page',
     async () => {
       await vm.addNIC(multusNetworkInterface);
-      expect(await vm.getAttachedNICs()).toContain(multusNetworkInterface);
-      await vm.action(VM_ACTION.Start);
+      expect(await vm.hasNIC(multusNetworkInterface)).toBeTruthy();
+      await vm.detailViewAction(VM_ACTION.Start);
       expect(
         _.find(getInterfaces(vm.getResource()), (o) => o.name === multusNetworkInterface.name),
       ).toBeDefined();
-      await vm.action(VM_ACTION.Stop);
+      await vm.detailViewAction(VM_ACTION.Stop);
       await vm.removeNIC(multusNetworkInterface.name);
-      expect(await vm.getAttachedNICs()).not.toContain(multusNetworkInterface);
+      expect(await vm.hasNIC(multusNetworkInterface)).not.toBeTruthy();
     },
     VM_ACTIONS_TIMEOUT_SECS,
   );
@@ -102,19 +100,19 @@ describe('Add/remove disks and NICs on respective VM pages', () => {
       };
       await vm.addNIC(multusNetworkInterface);
       await vm.addNIC(secondMultusInterface);
-      expect(await vm.getAttachedNICs()).toContain(multusNetworkInterface);
-      expect(await vm.getAttachedNICs()).toContain(secondMultusInterface);
-      await vm.action(VM_ACTION.Start);
+      expect(await vm.hasNIC(multusNetworkInterface)).toBeTruthy();
+      expect(await vm.hasNIC(secondMultusInterface)).toBeTruthy();
+      await vm.detailViewAction(VM_ACTION.Start);
       const vmInterfaces = _.filter(
         getInterfaces(vm.getResource()),
         (o) => o.name === multusNetworkInterface.name || o.name === secondMultusInterface.name,
       );
       expect(vmInterfaces.length).toEqual(2);
-      await vm.action(VM_ACTION.Stop);
+      await vm.detailViewAction(VM_ACTION.Stop);
       await vm.removeNIC(multusNetworkInterface.name);
       await vm.removeNIC(secondMultusInterface.name);
-      expect(await vm.getAttachedNICs()).not.toContain(multusNetworkInterface);
-      expect(await vm.getAttachedNICs()).not.toContain(secondMultusInterface);
+      expect(await vm.hasNIC(multusNetworkInterface)).not.toBeTruthy();
+      expect(await vm.hasNIC(secondMultusInterface)).not.toBeTruthy();
     },
     VM_ACTIONS_TIMEOUT_SECS,
   );
@@ -126,6 +124,11 @@ describe('Test network type presets and options', () => {
   const wizard = new Wizard();
   const leakedResources = new Set<string>();
 
+  const vm = new VMBuilder(getBasicVMBuilder())
+    .setProvisionSource(ProvisionSource.URL)
+    .setCustomize(true)
+    .build();
+
   beforeAll(async () => {
     createResource(multusNAD);
   });
@@ -137,56 +140,87 @@ describe('Test network type presets and options', () => {
   it('ID(CNV-2073) Test NIC default type in VM Wizard', async () => {
     await browser.get(`${appHost}/k8s/ns/${testName}/virtualization`);
     await isLoaded();
-    await wizard.openWizard(VirtualMachineModel);
+    await wizard.openWizard(VirtualMachineModel, true);
 
-    await wizard.fillName(getRandStr(5));
-    await wizard.fillDescription(testName);
-    await wizard.selectProvisionSource({
-      method: DISK_SOURCE.Container,
-      source: basicVMConfig.sourceContainer,
-    });
-    await wizard.selectOperatingSystem(basicVMConfig.operatingSystem);
-    await wizard.selectFlavor(basicVMConfig.flavorConfig);
-    await wizard.selectWorkloadProfile(basicVMConfig.workloadProfile);
-    await wizard.next();
+    await wizard.processGeneralStep(vm.getData());
 
     // Default type for Pod Networking NIC is masquerade
-    expect(
-      wizardView.tableRowAttribute(defaultWizardPodNetworkingInterface.name, networkTabCol.type),
-    ).toEqual(NIC_TYPE.masquerade);
+    const podNic = await wizardView.tableRowAttribute(
+      defaultPodNetworkingInterface.name,
+      networkTabCol.type,
+    );
+    expect(podNic.toLowerCase()).toEqual(NIC_TYPE.masquerade.toLowerCase());
 
     // All type options are available for Pod Networking
     await click(wizardView.addNICButton);
-    expect((await getSelectOptions(nicType)).sort()).toEqual(bindingMethods);
+    await click(nicType);
+    const actualBindingMethods = await getListTexts(dropDownList);
+    expect(actualBindingMethods.sort()).toEqual(bindingMethods);
+    await click(dropDownList.get(0));
     await click(wizardView.modalCancelButton);
     await wizard.addNIC(multusNetworkInterface);
     await wizardView.clickKebabAction(multusNetworkInterface.name, 'Edit');
     // expect masquerade is not available option
-    expect((await getSelectOptions(nicType)).sort()).toEqual(nonPodNetworkBindingMethods);
+    await click(nicType);
+    const actualNonPodBindingMethods = await getListTexts(dropDownList);
+    expect(actualNonPodBindingMethods.sort()).toEqual(nonPodNetworkBindingMethods);
+    await click(dropDownList.get(0));
     await click(wizardView.modalCancelButton);
     await wizard.closeWizard();
   });
 
   it('ID(CNV-4038) Test NIC default type in example VM', async () => {
     await createExampleVMViaYAML();
-    const vm = new VirtualMachine({ name: DEFAULT_YAML_VM_NAME, namespace: testName });
+    const exampleVM = new VirtualMachine({ name: DEFAULT_YAML_VM_NAME, namespace: testName });
     const NICDialog = new NetworkInterfaceDialog();
-    await withResource(leakedResources, vm.asResource(), async () => {
-      await vm.navigateToTab(TAB.NetworkInterfaces);
+    await withResource(leakedResources, exampleVM.asResource(), async () => {
+      await exampleVM.navigateToNICs();
 
       expect(
-        _.findIndex(await vm.getAttachedNICs(), (x) => {
-          return _.isMatch(
-            x,
-            _.pick(defaultYAMLPodNetworkingInterface, ['name', 'model', 'network']),
-          );
+        _.findIndex(await exampleVM.getAttachedNICs(), (x) => {
+          return _.isMatch(x, _.pick(defaultPodNetworkingInterface, ['name', 'model', 'network']));
         }) > -1,
       ).toBe(true);
 
       await click(createNICButton);
       await NICDialog.selectNetwork(multusNAD.metadata.name);
-      expect((await getSelectOptions(nicType)).sort()).toEqual(nonPodNetworkBindingMethods);
-      await vm.navigateToListView();
+      await click(nicType);
+      const actualNonPodBindingMethods = await getListTexts(dropDownList);
+      expect(actualNonPodBindingMethods.sort()).toEqual(nonPodNetworkBindingMethods);
+      await click(dropDownList.get(0));
+      await exampleVM.navigateToListView();
     });
   });
+
+  it('ID(CNV-4781) Test NIC supported models in VM Wizard', async () => {
+    await browser.get(`${appHost}/k8s/ns/${testName}/virtualization`);
+    await isLoaded();
+    await wizard.openWizard(VirtualMachineModel, true);
+
+    await wizard.processGeneralStep(vm.getData());
+
+    await click(wizardView.addNICButton);
+    await click(nicModel);
+    const actualModels = await getListTexts(dropDownList);
+    expect(actualModels).toEqual([NIC_MODEL.VirtIO, NIC_MODEL.e1000e]);
+    await click(dropDownList.get(0));
+
+    await click(wizardView.modalCancelButton);
+    await wizard.closeWizard();
+  });
+
+  it('ID(CNV-4780) NIC model is disabled when sriov is selected in VM Wizard', async () => {
+    await browser.get(`${appHost}/k8s/ns/${testName}/virtualization`);
+    await isLoaded();
+    await wizard.openWizard(VirtualMachineModel, true);
+
+    await wizard.processGeneralStep(vm.getData());
+
+    await click(wizardView.addNICButton);
+    await selectItemFromDropdown(nicType, dropDownItemMain(NIC_TYPE.sriov));
+    expect(nicModel.isEnabled()).toBe(false);
+
+    await click(wizardView.modalCancelButton);
+    await wizard.closeWizard();
+  });
 });
