@@ -19,6 +19,7 @@ import {
 } from '@patternfly/react-core';
 import { CaretDownIcon, FilterIcon, ColumnsIcon } from '@patternfly/react-icons';
 import { Dropdown as DropdownInternal } from '@console/internal/components/utils';
+import { useTranslation } from 'react-i18next';
 
 import { setQueryArgument, removeQueryArgument } from './utils';
 import { filterList } from '../actions/k8s';
@@ -96,13 +97,34 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
     location,
     textFilter = filterTypeMap[FilterType.NAME],
     labelFilter = filterTypeMap[FilterType.LABEL],
+    uniqueFilterName,
   } = props;
 
+  const { t } = useTranslation();
+  const translateFilterType = (value: string) => {
+    switch (value) {
+      case 'Name':
+        return t('filter-toolbar~Name');
+      case 'Label':
+        return t('filter-toolbar~Label');
+      default:
+        return value;
+    }
+  };
+  const filterDropdownItems = {
+    NAME: t('filter-toolbar~Name'),
+    LABEL: t('filter-toolbar~Label'),
+  };
+
+  // use unique name only when only when more than 1 table is in the view
+  const uniqTextFilter = uniqueFilterName ? `${uniqueFilterName}-${textFilter}` : textFilter;
+  const uniqlabelFilter = uniqueFilterName ? `${uniqueFilterName}-${labelFilter}` : labelFilter;
+
   const [inputText, setInputText] = React.useState('');
   const [filterType, setFilterType] = React.useState(FilterType.NAME);
   const [isOpen, setOpen] = React.useState(false);
   const [placeholder, setPlaceholder] = React.useState(
-    nameFilterPlaceholder || 'Search by name...',
+    nameFilterPlaceholder || t('filter-toolbar~Search by name...'),
   );
 
   // (rowFilters) => {'rowFilterTypeA': ['staA', 'staB'], 'rowFilterTypeB': ['stbA'] }
@@ -134,8 +156,8 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
   const { name: nameFilter, labels: labelFilters, rowFiltersFromURL: selectedRowFilters } = (() => {
     const rowFiltersFromURL: string[] = [];
     const params = new URLSearchParams(location.search);
-    const q = params.get(labelFilter);
-    const name = params.get(textFilter);
+    const q = params.get(uniqlabelFilter);
+    const name = params.get(uniqTextFilter);
     _.map(filterKeys, (f) => {
       const vals = params.get(f);
       if (vals) {
@@ -156,9 +178,9 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
 
   const updateLabelFilter = (filterValues: string[]) => {
     if (filterValues.length > 0) {
-      setQueryArgument(labelFilter, filterValues.join(','));
+      setQueryArgument(uniqlabelFilter, filterValues.join(','));
     } else {
-      removeQueryArgument(labelFilter);
+      removeQueryArgument(uniqlabelFilter);
     }
     setInputText('');
     applyFilter(filterValues, FilterType.LABEL);
@@ -166,9 +188,9 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
 
   const updateNameFilter = (filterValue: string) => {
     if (!_.isEmpty(filterValue)) {
-      setQueryArgument(textFilter, filterValue);
+      setQueryArgument(uniqTextFilter, filterValue);
     } else {
-      removeQueryArgument(textFilter);
+      removeQueryArgument(uniqTextFilter);
     }
     setInputText(filterValue);
     applyFilter(filterValue, FilterType.NAME);
@@ -262,10 +284,10 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
     setFilterType(FilterType[type]);
     switch (FilterType[type]) {
       case 'Name':
-        setPlaceholder(nameFilterPlaceholder || 'Search by name...');
+        setPlaceholder(nameFilterPlaceholder || t('filter-toolbar~Search by name...'));
         break;
       case 'Label':
-        setPlaceholder(labelFilterPlaceholder || 'Search by label...');
+        setPlaceholder(labelFilterPlaceholder || t('filter-toolbar~Search by label...'));
         break;
       default:
         setPlaceholder('app=frontend');
@@ -275,7 +297,12 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
 
   const dropdownItems = getDropdownItems(rowFilters, selectedRowFilters, data, props);
   return (
-    <Toolbar id="filter-toolbar" clearAllFilters={clearAll}>
+    <Toolbar
+      data-test="filter-toolbar"
+      id="filter-toolbar"
+      clearAllFilters={clearAll}
+      clearFiltersButtonText={t('filter-toolbar~Clear all filters')}
+    >
       <ToolbarContent>
         {rowFilters.length > 0 && (
           <ToolbarItem>
@@ -305,7 +332,7 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
                     toggleIndicator={CaretDownIcon}
                   >
                     <FilterIcon className="span--icon__right-margin" />
-                    Filter
+                    {t('filter-toolbar~Filter')}
                   </DropdownToggle>
                 }
               />,
@@ -320,20 +347,20 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
               deleteChip={(filter, chip: string) =>
                 updateLabelFilter(_.difference(labelFilters, [chip]))
               }
-              categoryName="Label"
+              categoryName={t('filter-toolbar~Label')}
             >
               <ToolbarFilter
                 chips={nameFilter && nameFilter.length > 0 ? [nameFilter] : []}
                 deleteChip={() => updateNameFilter('')}
-                categoryName="Name"
+                categoryName={t('filter-toolbar~Name')}
               >
                 <div className="pf-c-input-group">
                   {!hideLabelFilter && (
                     <DropdownInternal
-                      items={FilterType}
+                      items={filterDropdownItems}
                       onChange={switchFilter}
                       selectedKey={filterType}
-                      title={filterType}
+                      title={translateFilterType(filterType)}
                     />
                   )}
                   <AutocompleteInput
@@ -355,7 +382,7 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
         )}
         {columnLayout?.id && !hideColumnManagement && (
           <ToolbarItem>
-            <Tooltip content="Manage columns">
+            <Tooltip content={t('filter-toolbar~Manage columns')}>
               <Button
                 variant="plain"
                 onClick={() =>
@@ -363,7 +390,7 @@ const FilterToolbar_: React.FC<FilterToolbarProps & RouteComponentProps> = (prop
                     columnLayout,
                   })
                 }
-                aria-label="Column Management"
+                aria-label={t('filter-toolbar~Column management')}
               >
                 <ColumnsIcon />
               </Button>
@@ -391,6 +418,8 @@ type FilterToolbarProps = {
   columnLayout?: ColumnLayout;
   nameFilterPlaceholder?: string;
   labelFilterPlaceholder?: string;
+  // Used when multiple tables are in the same page
+  uniqueFilterName?: string;
 };
 
 export type RowFilter<R = any> = {
