@@ -5,8 +5,8 @@ import { sortable } from '@patternfly/react-table';
 import * as classNames from 'classnames';
 import { getMachineAWSPlacement, getMachineRole } from '@console/shared';
 import { Tooltip, Button } from '@patternfly/react-core';
-
 import { PencilAltIcon } from '@patternfly/react-icons';
+import { useTranslation } from 'react-i18next';
 
 import { MachineAutoscalerModel, MachineModel, MachineSetModel } from '../models';
 import { K8sKind, MachineDeploymentKind, MachineSetKind, referenceForModel } from '../module/k8s';
@@ -22,7 +22,6 @@ import {
   SectionHeading,
   Selector,
   navFactory,
-  pluralize,
   resourcePath,
   useAccessReview,
 } from './utils';
@@ -35,15 +34,19 @@ const machineReplicasModal = (
   configureReplicaCountModal({
     resourceKind,
     resource,
-    title: 'Edit Machine Count',
-    message: `${resourceKind.labelPlural} maintain the proper number of healthy machines.`,
+    // t('machine-sets~Edit Machine count')
+    titleKey: 'machine-sets~Edit Machine count',
+    // t('machine-sets~{{resourceKind}} maintain the proper number of healthy machines.')
+    messageKey: 'machine-sets~{{resourceKind}} maintain the proper number of healthy machines.',
+    messageVariables: { resourceKind: resourceKind.labelPlural },
   });
 
 export const editCountAction: KebabAction = (
   kind: K8sKind,
   resource: MachineSetKind | MachineDeploymentKind,
 ) => ({
-  label: 'Edit Machine Count',
+  // t('machine-sets~Edit Machine count')
+  labelKey: 'machine-sets~Edit Machine count',
   callback: () => machineReplicasModal(kind, resource),
   accessReview: {
     group: kind.apiGroup,
@@ -55,7 +58,8 @@ export const editCountAction: KebabAction = (
 });
 
 const configureMachineAutoscaler: KebabAction = (kind: K8sKind, machineSet: MachineSetKind) => ({
-  label: 'Create Autoscaler',
+  // t('machine-sets~Create MachineAutoscaler')
+  labelKey: 'machine-sets~Create MachineAutoscaler',
   callback: () => configureMachineAutoscalerModal({ machineSet, cancel: _.noop, close: _.noop }),
   accessReview: {
     group: MachineAutoscalerModel.apiGroup,
@@ -94,69 +98,6 @@ const tableColumnClasses = [
   Kebab.columnClass,
 ];
 
-const MachineSetTableHeader = () => {
-  return [
-    {
-      title: 'Name',
-      sortField: 'metadata.name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[0] },
-    },
-    {
-      title: 'Namespace',
-      sortField: 'metadata.namespace',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[1] },
-      id: 'namespace',
-    },
-    {
-      title: 'Machines',
-      sortField: 'status.replicas',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[2] },
-    },
-    {
-      title: '',
-      props: { className: tableColumnClasses[3] },
-    },
-  ];
-};
-MachineSetTableHeader.displayName = 'MachineSetTableHeader';
-
-const MachineSetTableRow: RowFunction<MachineSetKind> = ({ obj, index, key, style }) => {
-  return (
-    <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
-      <TableData className={tableColumnClasses[0]}>
-        <ResourceLink
-          kind={machineSetReference}
-          name={obj.metadata.name}
-          namespace={obj.metadata.namespace}
-        />
-      </TableData>
-      <TableData
-        className={classNames(tableColumnClasses[1], 'co-break-word')}
-        columnID="namespace"
-      >
-        <ResourceLink kind="Namespace" name={obj.metadata.namespace} />
-      </TableData>
-      <TableData className={tableColumnClasses[2]}>
-        <Link
-          to={`${resourcePath(
-            machineSetReference,
-            obj.metadata.name,
-            obj.metadata.namespace,
-          )}/machines`}
-        >
-          {getReadyReplicas(obj)} of {getDesiredReplicas(obj)} machines
-        </Link>
-      </TableData>
-      <TableData className={tableColumnClasses[3]}>
-        <ResourceKebab actions={menuActions} kind={machineSetReference} resource={obj} />
-      </TableData>
-    </TableRow>
-  );
-};
-
 export const MachineCounts: React.SFC<MachineCountsProps> = ({
   resourceKind,
   resource,
@@ -181,15 +122,18 @@ export const MachineCounts: React.SFC<MachineCountsProps> = ({
     name: resource.metadata.name,
     namespace: resource.metadata.namespace,
   });
+  const { t } = useTranslation();
+  const desiredReplicasText = `${desiredReplicas}  ${t('machine-sets~machine', {
+    count: desiredReplicas,
+  })}`;
 
-  const desiredReplicasText = pluralize(desiredReplicas, 'machine');
   return (
     <div className="co-m-pane__body-group">
       <div className="co-detail-table">
         <div className="co-detail-table__row row">
           <div className="co-detail-table__section">
             <dl className="co-m-pane__details">
-              <dt className="co-detail-table__section-header">Desired Count</dt>
+              <dt className="co-detail-table__section-header">{t('machine-sets~Desired count')}</dt>
               <dd>
                 {canUpdate ? (
                   <Button variant="link" type="button" isInline onClick={editReplicas}>
@@ -204,30 +148,46 @@ export const MachineCounts: React.SFC<MachineCountsProps> = ({
           </div>
           <div className="co-detail-table__section">
             <dl className="co-m-pane__details">
-              <dt className="co-detail-table__section-header">Current Count</dt>
+              <dt className="co-detail-table__section-header">{t('machine-sets~Current count')}</dt>
               <dd>
-                <Tooltip content="The most recently observed number of replicas.">
-                  <span>{pluralize(replicas, 'machine')}</span>
+                <Tooltip content={t('machine-sets~The most recently observed number of replicas.')}>
+                  <span>
+                    {replicas} {t('machine-sets~machine', { count: replicas })}
+                  </span>
                 </Tooltip>
               </dd>
             </dl>
           </div>
           <div className="co-detail-table__section">
             <dl className="co-m-pane__details">
-              <dt className="co-detail-table__section-header">Ready Count</dt>
+              <dt className="co-detail-table__section-header">{t('machine-sets~Ready count')}</dt>
               <dd>
-                <Tooltip content="The number of ready replicas for this MachineSet. A machine is considered ready when the node has been created and is ready.">
-                  <span>{pluralize(readyReplicas, 'machine')}</span>
+                <Tooltip
+                  content={t(
+                    'machine-sets~The number of ready replicas for this MachineSet. A machine is considered ready when the node has been created and is ready.',
+                  )}
+                >
+                  <span>
+                    {readyReplicas} {t('machine-sets~machine', { count: readyReplicas })}
+                  </span>
                 </Tooltip>
               </dd>
             </dl>
           </div>
           <div className="co-detail-table__section co-detail-table__section--last">
             <dl className="co-m-pane__details">
-              <dt className="co-detail-table__section-header">Available Count</dt>
+              <dt className="co-detail-table__section-header">
+                {t('machine-sets~Available count')}
+              </dt>
               <dd>
-                <Tooltip content="The number of available replicas (ready for at least minReadySeconds) for this MachineSet.">
-                  <span>{pluralize(availableReplicas, 'machine')}</span>
+                <Tooltip
+                  content={t(
+                    'machine-sets~The number of available replicas (ready for at least minReadySeconds) for this MachineSet.',
+                  )}
+                >
+                  <span>
+                    {availableReplicas} {t('machine-sets~machine', { count: availableReplicas })}
+                  </span>
                 </Tooltip>
               </dd>
             </dl>
@@ -249,53 +209,123 @@ export const MachineTabPage: React.SFC<MachineTabPageProps> = ({
 const MachineSetDetails: React.SFC<MachineSetDetailsProps> = ({ obj }) => {
   const machineRole = getMachineRole(obj);
   const { availabilityZone, region } = getMachineAWSPlacement(obj);
+  const { t } = useTranslation();
   return (
     <>
       <div className="co-m-pane__body">
-        <SectionHeading text="Machine Set Details" />
+        <SectionHeading text={t('machine-sets~Machine set details')} />
         <MachineCounts resourceKind={MachineSetModel} resource={obj} />
-        <ResourceSummary resource={obj}>
-          <dt>Selector</dt>
-          <dd>
-            <Selector
-              kind={machineReference}
-              selector={obj.spec?.selector}
-              namespace={obj.metadata.namespace}
-            />
-          </dd>
-          {machineRole && (
-            <>
-              <dt>Machine Role</dt>
-              <dd>{machineRole}</dd>
-            </>
-          )}
-          {region && (
-            <>
-              <dt>Region</dt>
-              <dd>{region}</dd>
-            </>
-          )}
-          {availabilityZone && (
-            <>
-              <dt>Availability Zone</dt>
-              <dd>{availabilityZone}</dd>
-            </>
-          )}
-        </ResourceSummary>
+        <div className="row">
+          <div className="col-md-6">
+            <ResourceSummary resource={obj}>
+              <dt>{t('machine-sets~Selector')}</dt>
+              <dd>
+                <Selector
+                  kind={machineReference}
+                  selector={obj.spec?.selector}
+                  namespace={obj.metadata.namespace}
+                />
+              </dd>
+              {machineRole && (
+                <>
+                  <dt>{t('machine-sets~Machine role')}</dt>
+                  <dd>{machineRole}</dd>
+                </>
+              )}
+              {region && (
+                <>
+                  <dt>{t('machine-sets~Region')}</dt>
+                  <dd>{region}</dd>
+                </>
+              )}
+              {availabilityZone && (
+                <>
+                  <dt>{t('machine-sets~Availability zone')}</dt>
+                  <dd>{availabilityZone}</dd>
+                </>
+              )}
+            </ResourceSummary>
+          </div>
+        </div>
       </div>
     </>
   );
 };
 
-export const MachineSetList: React.SFC = (props) => (
-  <Table
-    {...props}
-    aria-label="Machine Sets"
-    Header={MachineSetTableHeader}
-    Row={MachineSetTableRow}
-    virtualize
-  />
-);
+export const MachineSetList: React.SFC = (props) => {
+  const { t } = useTranslation();
+  const MachineSetTableHeader = () => {
+    return [
+      {
+        title: t('machine-sets~Name'),
+        sortField: 'metadata.name',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[0] },
+      },
+      {
+        title: t('machine-sets~Namespace'),
+        sortField: 'metadata.namespace',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[1] },
+        id: 'namespace',
+      },
+      {
+        title: t('machine-sets~Machines'),
+        sortField: 'status.replicas',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[2] },
+      },
+      {
+        title: '',
+        props: { className: tableColumnClasses[3] },
+      },
+    ];
+  };
+
+  const MachineSetTableRow: RowFunction<MachineSetKind> = ({ obj, index, key, style }) => {
+    return (
+      <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
+        <TableData className={tableColumnClasses[0]}>
+          <ResourceLink
+            kind={machineSetReference}
+            name={obj.metadata.name}
+            namespace={obj.metadata.namespace}
+          />
+        </TableData>
+        <TableData
+          className={classNames(tableColumnClasses[1], 'co-break-word')}
+          columnID="namespace"
+        >
+          <ResourceLink kind="Namespace" name={obj.metadata.namespace} />
+        </TableData>
+        <TableData className={tableColumnClasses[2]}>
+          <Link
+            to={`${resourcePath(
+              machineSetReference,
+              obj.metadata.name,
+              obj.metadata.namespace,
+            )}/machines`}
+          >
+            {getReadyReplicas(obj)} {t('machine-sets~of')} {getDesiredReplicas(obj)}{' '}
+            {t('machine-sets~machines')}
+          </Link>
+        </TableData>
+        <TableData className={tableColumnClasses[3]}>
+          <ResourceKebab actions={menuActions} kind={machineSetReference} resource={obj} />
+        </TableData>
+      </TableRow>
+    );
+  };
+  return (
+    <Table
+      {...props}
+      aria-label={t('machine-sets~Machine sets')}
+      Header={MachineSetTableHeader}
+      Row={MachineSetTableRow}
+      virtualize
+    />
+  );
+};
 
 export const MachineSetPage: React.SFC<MachineSetPageProps> = (props) => (
   <ListPage {...props} ListComponent={MachineSetList} kind={machineSetReference} canCreate />
